using System;
using System.IO;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;

using Phidgets; 
using Phidgets.Events; 

namespace DataLogger {
    class Code {

        // Obtain an initial time from which to generate timestamps
        public static Stopwatch stopwatch = Stopwatch.StartNew();

        // Clear and open the file for writing
        public static FileStream outFile = new FileStream(@"temperature_data_csharp.csv", FileMode.Create);

        static void Main(string[] args) {
            try {
                
                // Print a text header to the file first thing
                string header = "Time,Thermocouple-Temperature,Ambient-Board-Temperature\n";
                System.Text.ASCIIEncoding encoding = new System.Text.ASCIIEncoding();
                Byte[] bytes = encoding.GetBytes(header);
                outFile.Write(bytes, 0, bytes.Length);
                outFile.Flush();

                // Create the Phidget software object, hook in the event function, and open the object
                TemperatureSensor device = new TemperatureSensor(); 
                device.TemperatureChange += new TemperatureChangeEventHandler(temperatureDataHandler);
                device.open();
                device.waitForAttachment();

                // Set the thermocouple type and trigger on port [0] (0 = record all data)    
                device.thermocouples[0].Sensitivity = 0;
                device.thermocouples[0].Type =
                    TemperatureSensorSensor.ThermocoupleType.PHIDGET_TEMPERATURE_SENSOR_K_TYPE;

                Console.WriteLine("Press Enter to end anytime...");
                Console.Read();

                device.close();
                device = null;
            }
            catch (PhidgetException ex) { Console.WriteLine(ex.Description); }

        }

        // Create a listener function to handle all temperature data events 
        static void temperatureDataHandler(object sender, TemperatureChangeEventArgs e) {
            double microseconds = stopwatch.ElapsedMilliseconds / 1000.0;

            // Start composing a string of data from this event
            string data = microseconds + "," + e.Temperature + ",";

            // Get the board temperature and add it to the string
            data = data + ((TemperatureSensor)sender).ambientSensor.Temperature + "\n";

            // The raw write method involves translating our string into bytes, like Java
            System.Text.ASCIIEncoding  encoding = new System.Text.ASCIIEncoding();
            Byte[] bytes = encoding.GetBytes(data);
            outFile.Write(bytes, 0, bytes.Length);

            // Print a dot to the console to indicate another more data written
            Console.Write(".");
            Console.Out.Flush();
        }
    }
}

//============================================================================
// EOF
//============================================================================

